@@ -5,12 +5,14 @@ from . import manifold_np,  manifold
 from .core import problem, backbone_autograd, backbone_torch
 
 try:
+    import torch
     from . import manifold_torch
 except ImportError:
     print('No torch package installed')
 
 
 try:
+    import jax 
     from .core  import backbone_jax
 except ImportError:
     print('No JAX package installed')
